EPRI Audible Noise
========================

The following are the AC and DC audible noise empirical formula developed by
the Electric Power Research Institute (EPRI).

AC
========================

Constants:

.. image:: helpdocs/equations/epri_ac_constants.png

Generated acoustic power:

.. image:: helpdocs/equations/epri_ac_gap.png

L_5 sound pressure level:

.. image:: helpdocs/equations/epri_ac_spl_5.png

Correction factor calculation:

.. image:: helpdocs/equations/epri_ac_E_c.png
.. image:: helpdocs/equations/epri_ac_delta_gap.png

L_50 sound pressure level:

.. image:: helpdocs/equations/epri_ac_spl_50.png

Total sound pressure level from all phases:

.. image:: helpdocs/equations/spl_sum.png

Fair weather correction factor:

.. image:: helpdocs/equations/epri_ac_fair_corr.png

DC
========================

Constants:

.. image:: helpdocs/equations/epri_dc_constants.png

Generated acoustic power:

.. image:: helpdocs/equations/epri_dc_gap.png

Sound pressure level:

.. image:: helpdocs/equations/epri_dc_spl_50.png

Total sound pressure level from all phases:

.. image:: helpdocs/equations/spl_sum.png

Foul weather correction factor:

.. image:: helpdocs/equations/epri_dc_foul_corr.png

Seasonal correction factor:

.. image:: helpdocs/equations/epri_dc_winter_corr.png
.. image:: helpdocs/equations/epri_dc_spring_corr.png
